/******************************************************************************/
/*  			Copyright Spark Fun Electronics                               */
/******************************************************************************/
/*                                                                            */
/*  gps.c:  functions for the Lassen IQ GPS in NMEA mode                      */
/*                                                                            */
/*  3-20-05: Removed Lat/Lon averaging to fix "warmup" bug.                   */
/*                                                                            */
/******************************************************************************/

//*******************************************************
//					Libraries
//*******************************************************
#include "gps.h"
#include <stdio.h>
#include "serial.h"
#include "rprintf.h"

//Needed for uint8_t
#include <stdint.h>

#include <stdlib.h>
#include <string.h>


//*******************************************************
//					Global Variables for gps.c
//*******************************************************
const char gps_init_string408[]="$PSRF103,01,00,00,01*25\r\n"	//Turn off GLL messages
"$PSRF103,02,00,00,01*26\r\n"	//Turn off GSA messages
"$PSRF103,03,00,00,01*27\r\n"	//Turn off GSV messages
"$PSRF103,04,00,00,01*20\r\n"	//Turn off RMC messages
"$PSRF103,05,00,00,01*21\r\n"	//Turn off VTG messages
"$PSRF103,06,00,00,01*22\r\n"	//Turn off ??? messages
"$PSRF103,07,00,00,01*23\r\n"	//Turn off ??? messages
"$PSRF103,00,00,00,01*24\r\n"	//Turn off GGA messages
//"$PSRF103,00,00,01,00*24\r\n";	//Set GGA messages to 1 Hz rate with checksum disabled!
//"$PSRF103,04,00,01,01*21\r\n";	//Set RMC messages to 1 Hz rate with checksum enabled
"$PSRF103,04,00,01,00*20\r\n";	//Set RMC messages to 1 Hz rate with checksum enabled

int locks = 0;

//*******************************************************
//					GPS Functions
//*******************************************************
//Usage: GPS_init_strings();
//Inputs: None
//Outputs: None
//Description: This function will initialize the GPS module
//				with the strings defined in the gps_init_string
//				array defined in the Global Varibales section.
void GPS_init_strings(void)
{
    for(int i=0; gps_init_string408[i] != '\0'; i++)
    {
        putc_serial1(gps_init_string408[i]);
    }
}

//Configure the GPS message with the specified frequency
//By default checksum is disabled

void config_gps_msgs(unsigned char const type, unsigned char const freq) {
	char gps_init_string[20];
	unsigned char cksum;
	
	sprintf( gps_init_string, "PSRF103,%d,00,%d,01", type, freq );
	GPS_CHECKSUM(gps_init_string,cksum) 

	putc_serial1('$');
	for(int i=0; gps_init_string[i] != '\0'; i++)
	{
		putc_serial1(gps_init_string[i]);
	}
	putc_serial1('*');
	putc_serial1(((cksum&0xF0)>>4)+'0');
	putc_serial1((cksum&0x0F)+'0');
	putc_serial1('\r');
	putc_serial1('\n');

}

void configure_gps_waas(unsigned char const enable){
	char gps_string[20];
	unsigned char cksum;
	
	sprintf( gps_string, "PSRF151,%d", enable );
	GPS_CHECKSUM(gps_string,cksum) 

	putc_serial1('$');
	for(int i=0; gps_string[i] != '\0'; i++)
	{
		putc_serial1(gps_string[i]);
	}
	putc_serial1('*');
	putc_serial1(((cksum&0xF0)>>4)+'0');
	putc_serial1((cksum&0x0F)+'0');
	putc_serial1('\r');
	putc_serial1('\n');
}


//Disable all possibile GPS messages that could be generated by the
//receiver.
void disable_all_gps_msgs(void) {
    config_gps_msgs( 0, 0 ); //Turn off GGA messages
    config_gps_msgs( 1, 0 ); //Turn off GLL messages
    config_gps_msgs( 2, 0 ); //Turn off GSA messages
    config_gps_msgs( 3, 0 ); //Turn off GSV messages
    config_gps_msgs( 4, 0 ); //Turn off RMC messages
    config_gps_msgs( 5, 0 ); //Turn off VTG messages
    config_gps_msgs( 6, 0 ); //Turn off MSS messages
    config_gps_msgs( 7, 0 ); //Turn off messages #7 --currently not defined--

}

//Enable the RMC message with the specified frequency
void enable_gps_rmc_msgs(unsigned char freq) {
    config_gps_msgs( 4, freq );
}

void disable_gps_rmc_msgs(void) {
    config_gps_msgs( 4, 0 );
}

void enable_gps_gga_msgs(unsigned char freq) {
    config_gps_msgs( 0, freq );
}

void disable_gps_gga_msgs(void) {
    config_gps_msgs( 0, 0 );
}

void enable_waas(void){
	configure_gps_waas(1);
}

void disable_waas(void){
	configure_gps_waas(0);
}
